package org.opengroup.osdu.notification.subscriptions;

import com.google.gson.JsonArray;
import com.google.gson.JsonObject;
import org.opengroup.osdu.core.common.Constants;

public class RecordUtils {

    private static final String domain = System.getProperty("DOMAIN", System.getenv("DOMAIN"));

    public static String createJsonRecordWithReference(int recordsCount, String id, String kind, String legalTag, String fromCrs, String conversionType, boolean isTestPartition) {

        JsonArray records = new JsonArray();

        for (int i = 0; i < recordsCount; i++) {

            JsonObject data = new JsonObject();
            data.addProperty("X", 16.00);
            data.addProperty("Y", 10.00);
            data.addProperty("Z", 0.0);

            JsonArray propertyNames = new JsonArray();
            propertyNames.add("X");
            propertyNames.add("Y");
            propertyNames.add("Z");

            JsonObject meta = new JsonObject();
            meta.addProperty(Constants.KIND, conversionType);
            meta.addProperty(Constants.PERSISTABLE_REFERENCE, fromCrs);
            meta.add(Constants.PROPERTY_NAMES, propertyNames);

            JsonArray metaBlocks = new JsonArray();
            metaBlocks.add(meta);

            JsonObject record = getRecordWithInputData(id + i, kind, legalTag, data, isTestPartition);
            record.add(Constants.META, metaBlocks);

            records.add(record);
        }

        return records.toString();
    }

    private static JsonObject getRecordWithInputData(String id, String kind, String legalTag, JsonObject data, boolean isTestPartition) {
        JsonObject record = getDefaultRecord(id, kind, legalTag, isTestPartition);
        record.add("data", data);
        return record;
    }

    private static JsonObject getDefaultRecord(String id, String kind, String legalTag, boolean isTestPartition) {
        JsonArray acls = new JsonArray();
        acls.add(String.format("data.test1@%s", getAclSuffix(isTestPartition)));
        return getDefaultRecordFromAcl(id, kind, legalTag, acls);
    }

    private static JsonObject getDefaultRecordFromAcl(String id, String kind, String legalTag, JsonArray acls) {
        JsonObject acl = new JsonObject();
        acl.add("viewers", acls);
        acl.add("owners", acls);

        JsonArray tags = new JsonArray();
        tags.add(legalTag);

        JsonArray ordcJson = new JsonArray();
        ordcJson.add("BR");

        JsonObject legal = new JsonObject();
        legal.add("legaltags", tags);
        legal.add("otherRelevantDataCountries", ordcJson);

        JsonObject record = new JsonObject();
        record.addProperty("id", id);
        record.addProperty("kind", kind);
        record.add("acl", acl);
        record.add("legal", legal);
        return record;
    }

    public static String getAclSuffix(boolean isTestPartition) {
        String environment = getEnvironment();
        //build.gradle currently throws exception if a variable is set to empty or not set at all
        //workaround by setting it to an "empty" string to construct the url
        if (!environment.isEmpty())
            environment = "." + environment;

        return String.format("%s%s.%s", TenantUtils.getTenantName(isTestPartition), environment, domain);
    }

    public static String getEnvironment() {
        return System.getProperty("DEPLOY_ENV", System.getenv("DEPLOY_ENV"));
    }
}
