// Copyright © Microsoft Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package org.opengroup.osdu.notification.api;

import org.opengroup.osdu.notification.util.Config;
import org.opengroup.osdu.notification.util.RestDescriptor;
import org.opengroup.osdu.notification.util.TestUtils;

import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

public class StorageIntegrationDescriptor extends RestDescriptor {

    protected static final String LEGAL_TAG = TestUtils.getOsduTenant() + "-test-tag";
    protected static final String DOMAIN = System.getProperty("DOMAIN", System.getenv("DOMAIN"));

    @Override
    public String getPath() {
        return "records";
    }

    @Override
    public String getHttpMethod() {
        return "PUT";
    }

    @Override
    public String getValidBody() {
        String postfix = String.format("%s.%s", TestUtils.getOsduTenant(), DOMAIN);
        return "[\n" +
                "  {\n" +
                "      \"data\":{\n" +
                "            \"Spuddate\":\"atspud\",\n" +
                "            \"UWI\":\"atuwi\",\n" +
                "            \"dlLatLongWGS84latitude\":\"latitude\",\n" +
                "            \"dlLatLongWGS84longitude\":\"longitude\"},\n" +
                "      \"version\":1591087431362345,\n" +
                "      \"kind\":\"opendes:at:wellbore:1.0.0\",\n" +
                "      \"acl\":{\n" +
                "            \"viewers\":[\n" +
                "                 \"data.test1@" + postfix + "\"],\n" +
                "            \"owners\":[\n" +
                "                 \"data.test1@" + postfix + "\"]},\n" +
                "      \"legal\":{\n" +
                "            \"legaltags\":[\n" +
                "                 \"" + LEGAL_TAG + "\"],\n" +
                "            \"otherRelevantDataCountries\":[\n" +
                "                 \"BR\"],\n" +
                "            \"status\":\"compliant\"},\n" +
                "      \"createUser\":\"integrationtest@opendes.iam.gserviceaccount.com\",\n" +
                "      \"createTime\":\"2020-06-01T18:32:52.054Z\",\n" +
                "      \"modifyUser\":\"integrationtest@opendes.iam.gserviceaccount.com\",\n" +
                "      \"modifyTime\":\"2020-06-02T08:43:51.553Z\"\n" +
                "  }\n" +
                "]";
    }

    @Override
    public Map<String, String> getOsduTenantHeaders() {
        Map<String, String> headers = new HashMap<>();
        headers.put("data-partition-id", Config.Instance().OsduTenant);
        headers.put("correlation-id", "storage-notification-it");
        return headers;
    }

    // Customer Tenant headers is not required by the current Storage -Notification
    // Integration Test scenario.It might be useful in upcoming test scenarios/cases
    @Override
    public Map<String, String> getCustomerTenantHeaders() {
        Map<String, String> headers = new HashMap<>();
        headers.put("data-partition-id", Config.Instance().ClientTenant);
        headers.put("correlation-id", "storage-notification-it");
        return headers;
    }
}